@@ -1,8 +1,11 @@
-#include <QtGui/QApplication>
+#include <libnotify/notify.h>
+
+#include "ui/vkgallery.h"
+
+#include <QApplication>
 #include <QObject>
 #include <QTranslator>
 #include <QLibraryInfo>
-#include "ui/vkgallery.h"
 
 int main(int argc, char *argv[])
 {
@@ -23,6 +26,9 @@ int main(int argc, char *argv[])
 	DATAPREFIX"/qt4/translations/");
     a.installTranslator(&commontr);
 
+    /* Init libnotify library */
+    notify_init(APP_NAME);
+
     VKGallery w;
     w.showMaximized();
     return a.exec();
